package MFTime;
use strict;
use warnings;

use rlib "./";

use MFScalar;
use base qw(MFScalar);

use SFTime;
our $SField = new SFTime;

1;
__END__
